@@ -1,5 +1,5 @@
 from fides.evaluation.ti_aggregation import AverageConfidenceTIAggregation
-from fides.evaluation.ti_evaluation import DistanceBasedTIEvaluation
+from fides.evaluation.ti_evaluation import MaxConfidenceTIEvaluation
 from simulations.environment import generate_and_run
 from simulations.model import SimulationConfiguration
 from simulations.peer import PeerBehavior
@@ -22,9 +22,9 @@ if __name__ == '__main__':
         pre_trusted_peers_count=0,
         initial_reputation=0.0,
         local_slips_acts_as=PeerBehavior.CONFIDENT_CORRECT,
-        evaluation_strategy=DistanceBasedTIEvaluation(),
+        evaluation_strategy=MaxConfidenceTIEvaluation(),
         ti_aggregation_strategy=AverageConfidenceTIAggregation()
     )
 
     result = generate_and_run(simulation_configuration)
-    plot_simulation_result(result, save_output='zero_gained_trust_all.png')
+    plot_simulation_result(result, save_output='figure_6_1.png')
